@@ -45,12 +45,12 @@ static int hkl_geometry_list_check_geometry_unit(const HklGeometryList *self,
 		geometry = hkl_geometry_list_item_geometry_get(item);
 
 		res = TRUE;
-		res &= DIAG(CHECK_AXIS_VALUE(geometry, "mu", mu * HKL_DEGTORAD));
-		res &= DIAG(CHECK_AXIS_VALUE(geometry, "omega", omega * HKL_DEGTORAD));
-		res &= DIAG(CHECK_AXIS_VALUE(geometry, "chi", chi * HKL_DEGTORAD));
-		res &= DIAG(CHECK_AXIS_VALUE(geometry, "phi", phi * HKL_DEGTORAD));
-		res &= DIAG(CHECK_AXIS_VALUE(geometry, "gamma", gamma * HKL_DEGTORAD));
-		res &= DIAG(CHECK_AXIS_VALUE(geometry, "delta", delta * HKL_DEGTORAD));
+		res &= CHECK_AXIS_VALUE(geometry, "mu", mu * HKL_DEGTORAD);
+		res &= CHECK_AXIS_VALUE(geometry, "omega", omega * HKL_DEGTORAD);
+		res &= CHECK_AXIS_VALUE(geometry, "chi", chi * HKL_DEGTORAD);
+		res &= CHECK_AXIS_VALUE(geometry, "phi", phi * HKL_DEGTORAD);
+		res &= CHECK_AXIS_VALUE(geometry, "gamma", gamma * HKL_DEGTORAD);
+		res &= CHECK_AXIS_VALUE(geometry, "delta", delta * HKL_DEGTORAD);
 
 		if (res)
 			break;
@@ -80,19 +80,19 @@ static void getter(void)
 	engine = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
 
 	/* geometry -> pseudo */
-	hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 0., 0., 60.);
+	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 0., 0., 60.));
 	res &= DIAG(check_pseudoaxes_v(engine, 0., 0., 1.));
 
-	hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 90., 0., 60.);
+	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 90., 0., 60.));
 	res &= DIAG(check_pseudoaxes_v(engine, 1., 0., 0.));
 
-	hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., -90., 0., 60.);
+	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., -90., 0., 60.));
 	res &= DIAG(check_pseudoaxes_v(engine, -1., 0., 0.));
 
-	hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 180., 0., 60.);
+	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 180., 0., 60.));
 	res &= DIAG(check_pseudoaxes_v(engine, 0., 0., -1.));
 
-	hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 45., 0., 135., 0., 90.);
+	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 45., 0., 135., 0., 90.));
 	res &= DIAG(check_pseudoaxes_v(engine, 1., 0., -1.));
 
 	ok(res == TRUE, "getter");
@@ -133,7 +133,7 @@ static void degenerated(void)
 		HklGeometryList *geometries;
 		size_t n_params;
 
-		hkl_engine_current_mode_set(engine, *mode, NULL);
+		res &= DIAG(hkl_engine_current_mode_set(engine, *mode, NULL));
 		parameters = hkl_engine_parameters_names_get(engine);
 		n_params = darray_size(*parameters);
 		if (n_params){
@@ -141,7 +141,7 @@ static void degenerated(void)
 
 			hkl_engine_parameters_values_get(engine, params, n_params, HKL_UNIT_DEFAULT);
 			params[0] = 0;
-			hkl_engine_parameters_values_set(engine, params, n_params, HKL_UNIT_DEFAULT, NULL);
+			res &= DIAG(hkl_engine_parameters_values_set(engine, params, n_params, HKL_UNIT_DEFAULT, NULL));
 		}
 
 		/* studdy this degenerated case */
@@ -193,14 +193,13 @@ static void q2(void)
 	modes = hkl_engine_modes_names_get(engine);
 
 	/* the init part */
-	hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 0., 0., 60.);
-	hkl_engine_initialized_set(engine, TRUE, NULL);
-
+	res &= DIAG(hkl_geometry_set_values_v(geometry, HKL_UNIT_USER, NULL, 0., 30., 0., 0., 0., 60.));
+	res &= DIAG(hkl_engine_initialized_set(engine, TRUE, NULL));
 
 	darray_foreach(mode, *modes){
 		double q, alpha;
 
-		hkl_engine_current_mode_set(engine, *mode, NULL);
+		res &= DIAG(hkl_engine_current_mode_set(engine, *mode, NULL));
 		for(q=0.1; q<1.; q += 0.1)
 			for(alpha = -M_PI; alpha<M_PI; alpha += M_PI/180.){
 				double values[] = {q, alpha};
@@ -248,7 +247,7 @@ static void petra3(void)
 
 	factory = hkl_factory_get_by_name("E6C", NULL);
 	geometry = hkl_factory_create_new_geometry(factory);
-	hkl_geometry_wavelength_set(geometry, 2.033, HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_geometry_wavelength_set(geometry, 2.033, HKL_UNIT_DEFAULT, NULL));
 
 	sample = hkl_sample_new("test");
 	lattice = hkl_lattice_new(7.813, 7.813, 7.813,
@@ -270,17 +269,16 @@ static void petra3(void)
 
 	/* set the psi pseudo axis */
 	psi = hkl_engine_list_engine_get_by_name(engines, "psi", NULL);
-	hkl_engine_current_mode_set(psi, "psi_constant_vertical", NULL);
 	/* set the mode parameters 0, 0, 1 */
-	hkl_engine_parameters_values_set(psi, psi_p, ARRAY_SIZE(psi_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(psi, psi_p, ARRAY_SIZE(psi_p), HKL_UNIT_DEFAULT, NULL));
 
 	/* Compute the hkl [1, 1, 0] in psi_constant_vertical mode with */
 	/* h2,k2,l2= [0, 0,1] and psi = 90 */
 	/* set the hkl pseudo axis in psi_constant_vertical */
 	hkl = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
-	hkl_engine_current_mode_set(hkl, "psi_constant_vertical", NULL);
+	res &= DIAG(hkl_engine_current_mode_set(hkl, "psi_constant_vertical", NULL));
 	/* set the mode parameters 0, 0, 1, 90. */
-	hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL));
 	geometries = hkl_engine_pseudo_axis_values_set(hkl, hkl_v, ARRAY_SIZE(hkl_v),
 							HKL_UNIT_DEFAULT, NULL);
 	if(geometries){
@@ -292,9 +290,9 @@ static void petra3(void)
 
 			hkl_geometry_set(geometry,
 					 hkl_geometry_list_item_geometry_get(item));
-			hkl_engine_initialized_set(psi, TRUE, NULL);
-			hkl_engine_pseudo_axis_values_get(psi, &current, 1,
-							   HKL_UNIT_DEFAULT, NULL);
+			res &= DIAG(hkl_engine_initialized_set(psi, TRUE, NULL));
+			res &= DIAG(hkl_engine_pseudo_axis_values_get(psi, &current, 1,
+								      HKL_UNIT_DEFAULT, NULL));
 			res &= DIAG(fabs(PSI - current) < HKL_EPSILON);
 		}
 		hkl_geometry_list_free(geometries);
@@ -338,7 +336,7 @@ static void petra3_2(void)
 
 	factory = hkl_factory_get_by_name("E6C", NULL);
 	geometry = hkl_factory_create_new_geometry(factory);
-	hkl_geometry_wavelength_set(geometry, 1.0332035, HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_geometry_wavelength_set(geometry, 1.0332035, HKL_UNIT_DEFAULT, NULL));
 
 	sample = hkl_sample_new("test");
 	lattice = hkl_lattice_new(5.1, 5.1, 5.1,
@@ -359,7 +357,7 @@ static void petra3_2(void)
 
 	/* set the hkl pseudo axis in psi_constant_vertical */
 	hkl = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
-	hkl_engine_current_mode_set(hkl, "psi_constant_vertical", NULL);
+	res &= DIAG(hkl_engine_current_mode_set(hkl, "psi_constant_vertical", NULL));
 	/* set the psi pseudo engine to read the psi value */
 	psi = hkl_engine_list_engine_get_by_name(engines, "psi", NULL);
 
@@ -370,12 +368,12 @@ static void petra3_2(void)
 	hkl_p[1] = 1;
 	hkl_p[2] = 0;
 	hkl_p[3] = PSI = 0;
-	hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL));
 	/* for psi */
 	psi_p[0] = 0;
 	psi_p[1] = 1;
 	psi_p[2] = 0;
-	hkl_engine_parameters_values_set(psi, psi_p, ARRAY_SIZE(psi_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(psi, psi_p, ARRAY_SIZE(psi_p), HKL_UNIT_DEFAULT, NULL));
 
 	/* freeze 0; ca 0 0 2 */
 	geometries = hkl_engine_set_values_v(hkl, 0., 0., 2.);
@@ -393,9 +391,9 @@ static void petra3_2(void)
 			double current;
 
 			hkl_geometry_set(geometry, hkl_geometry_list_item_geometry_get(item));
-			hkl_engine_initialized_set(psi, TRUE, NULL);
-			hkl_engine_pseudo_axis_values_get(psi, &current, 1,
-							   HKL_UNIT_DEFAULT, NULL);
+			res &= DIAG(hkl_engine_initialized_set(psi, TRUE, NULL));
+			res &= DIAG(hkl_engine_pseudo_axis_values_get(psi, &current, 1,
+								      HKL_UNIT_DEFAULT, NULL));
 			res &= DIAG(fabs(PSI - current) < HKL_EPSILON);
 		}
 		hkl_geometry_list_free(geometries);
@@ -403,7 +401,7 @@ static void petra3_2(void)
 
 	/* freeze 45; ca 0 0 2 */
 	hkl_p[3] = PSI = 45.0 * HKL_DEGTORAD;
-	hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL));
 	geometries = hkl_engine_set_values_v(hkl, 0., 0., 2.);
 
 	/*      del              th               chi              phi */
@@ -419,9 +417,9 @@ static void petra3_2(void)
 			double current;
 
 			hkl_geometry_set(geometry, hkl_geometry_list_item_geometry_get(item));
-			hkl_engine_initialized_set(psi, TRUE, NULL);
-			hkl_engine_pseudo_axis_values_get(psi, &current, 1,
-							   HKL_UNIT_DEFAULT, NULL);
+			res &= DIAG(hkl_engine_initialized_set(psi, TRUE, NULL));
+			res &= DIAG(hkl_engine_pseudo_axis_values_get(psi, &current, 1,
+								      HKL_UNIT_DEFAULT, NULL));
 			res &= DIAG(fabs(PSI - current) < HKL_EPSILON);
 		}
 		hkl_geometry_list_free(geometries);
@@ -434,14 +432,14 @@ static void petra3_2(void)
 	hkl_p[2] = 0;
 	hkl_p[3] = PSI = 0;
 	/* for hkl */
-	hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL));
 	geometries = hkl_engine_set_values_v(hkl, 0., 0., 2.);
 
 	/* for psi */
 	psi_p[0] = 1;
 	psi_p[1] = 1;
 	psi_p[2] = 0;
-	hkl_engine_parameters_values_set(psi, psi_p, ARRAY_SIZE(psi_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(psi, psi_p, ARRAY_SIZE(psi_p), HKL_UNIT_DEFAULT, NULL));
 
 	/*      del              th               chi              phi */
 	/*      23.37681         11.68839         90               -90 */
@@ -456,9 +454,9 @@ static void petra3_2(void)
 			double current;
 
 			hkl_geometry_set(geometry, hkl_geometry_list_item_geometry_get(item));
-			hkl_engine_initialized_set(psi, TRUE, NULL);
-			hkl_engine_pseudo_axis_values_get(psi, &current, 1,
-							   HKL_UNIT_DEFAULT, NULL);
+			res &= DIAG(hkl_engine_initialized_set(psi, TRUE, NULL));
+			res &= DIAG(hkl_engine_pseudo_axis_values_get(psi, &current, 1,
+								      HKL_UNIT_DEFAULT, NULL));
 			res &= DIAG(fabs(PSI - current) < HKL_EPSILON);
 		}
 		hkl_geometry_list_free(geometries);
@@ -467,7 +465,7 @@ static void petra3_2(void)
 	/* freeze 45; ca 0 0 2 */
 	hkl_p[3] = PSI = 45 * HKL_DEGTORAD;
 	/* for hkl */
-	hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG(hkl_engine_parameters_values_set(hkl, hkl_p, ARRAY_SIZE(hkl_p), HKL_UNIT_DEFAULT, NULL));
 	geometries = hkl_engine_set_values_v(hkl, 0., 0., 2.);
 
 	/*      del              th               chi              phi */
@@ -483,9 +481,9 @@ static void petra3_2(void)
 			double current;
 
 			hkl_geometry_set(geometry, hkl_geometry_list_item_geometry_get(item));
-			hkl_engine_initialized_set(psi, TRUE, NULL);
-			hkl_engine_pseudo_axis_values_get(psi, &current, 1,
-							   HKL_UNIT_DEFAULT, NULL);
+			res &= DIAG(hkl_engine_initialized_set(psi, TRUE, NULL));
+			res &= DIAG(hkl_engine_pseudo_axis_values_get(psi, &current, 1,
+								      HKL_UNIT_DEFAULT, NULL));
 			res &= DIAG(fabs(PSI - current) < HKL_EPSILON);
 		}
 		hkl_geometry_list_free(geometries);
@@ -499,7 +497,7 @@ static void petra3_2(void)
 	hkl_geometry_free(geometry);
 }
 
-int main(int argc, char** argv)
+int main(void)
 {
 	plan(5);
 
